Virtual Transport Interface - kombu.transport.virtual — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Virtual Transport Interface - kombu.transport.virtual

class `kombu.transport.virtual.` `Channel`(connection, **kwargs)
  class `Message`(channel, payload, **kwargs)
    `reject`()
  `Channel.` `basic_ack`(delivery_tag)
  `Channel.` `basic_cancel`(consumer_tag)
  `Channel.` `basic_consume`(queue, no_ack, callback, consumer_tag, **kwargs)
  `Channel.` `basic_get`(queue, **kwargs)
  `Channel.` `basic_publish`(message, exchange, routing_key, **kwargs)
  `Channel.` `basic_qos`(prefetch_size, prefetch_count, apply_global=False)
  `Channel.` `basic_recover`(requeue=False)
  `Channel.` `basic_reject`(delivery_tag, requeue=False)
  `Channel.` `close`()
  `Channel.` `drain_events`(timeout=None)
  `Channel.` `exchange_declare`(exchange, type='direct', durable=False, auto_delete=False, arguments=None)
  `Channel.` `exchange_delete`(exchange, if_unused=False)
  `Channel.` `flow`(active=True)
  `Channel.` `message_to_python`(raw_message)
  `Channel.` `prepare_message`(message_data, priority=None, content_type=None, content_encoding=None, headers=None, properties=None)
  `Channel.` `qos_manager`
  `Channel.` `queue_bind`(queue, exchange, routing_key, arguments=None)
  `Channel.` `queue_declare`(queue, **kwargs)
  `Channel.` `queue_delete`(queue, if_unusued=False, if_empty=False)
  `Channel.` `queue_purge`(queue, **kwargs)

class `kombu.transport.virtual.` `FairCycle`(fun, resources, predicate=<class 'Queue.Empty'>)

  Consume from a set of resources, where each resource gets an equal chance to be consumed from.

  `get`()

class `kombu.transport.virtual.` `Message`(channel, payload, **kwargs)
  `reject`()

class `kombu.transport.virtual.` `QualityOfService`(channel, prefetch_count=None, interval=None, do_restore=True)
  `ack`(delivery_tag)
  `append`(message, delivery_tag)
  `can_consume`()
  `requeue`(delivery_tag)
  `restore_unacked`()
  `restore_unacked_once`()

class `kombu.transport.virtual.` `Transport`(client, **kwargs)
  class `Channel`(connection, **kwargs)
    class `Message`(channel, payload, **kwargs)
      `reject`()
    `Transport.Channel.` `basic_ack`(delivery_tag)
    `Transport.Channel.` `basic_cancel`(consumer_tag)
    `Transport.Channel.` `basic_consume`(queue, no_ack, callback, consumer_tag, **kwargs)
    `Transport.Channel.` `basic_get`(queue, **kwargs)
    `Transport.Channel.` `basic_publish`(message, exchange, routing_key, **kwargs)
    `Transport.Channel.` `basic_qos`(prefetch_size, prefetch_count, apply_global=False)
    `Transport.Channel.` `basic_recover`(requeue=False)
    `Transport.Channel.` `basic_reject`(delivery_tag, requeue=False)
    `Transport.Channel.` `close`()
    `Transport.Channel.` `drain_events`(timeout=None)
    `Transport.Channel.` `exchange_declare`(exchange, type='direct', durable=False, auto_delete=False, arguments=None)
    `Transport.Channel.` `exchange_delete`(exchange, if_unused=False)
    `Transport.Channel.` `flow`(active=True)
    `Transport.Channel.` `message_to_python`(raw_message)
    `Transport.Channel.` `prepare_message`(message_data, priority=None, content_type=None, content_encoding=None, headers=None, properties=None)
    `Transport.Channel.` `qos_manager`
    `Transport.Channel.` `queue_bind`(queue, exchange, routing_key, arguments=None)
    `Transport.Channel.` `queue_declare`(queue, **kwargs)
    `Transport.Channel.` `queue_delete`(queue, if_unusued=False, if_empty=False)
    `Transport.Channel.` `queue_purge`(queue, **kwargs)
  `Transport.` `Cycle`

    alias of `FairCycle`

  `Transport.` `close_channel`(channel)
  `Transport.` `close_connection`(connection)
  `Transport.` `create_channel`(connection)
  `Transport.` `drain_events`(connection, timeout=None)
  `Transport.` `establish_connection`()

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »